==> treeland-debug-0.7.6-1-x86_64.pkg.tar.zst: usr/src/debug/treeland/treeland/src/.qt/rcc/qrc_qmake_Treeland.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xf0,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x79,0x5,0x35,0xf,0x0,0x76,0x16,0x42,0x1e,0x40,0x8f,0x1b,
  0xfd,0x79,0x73,0x89,0x14,0xfa,0x6d,0x69,0x7f,0x8e,0x64,0xcd,0xcf,0x1d,0x46,0x27,
  0xdb,0x60,0x4f,0xb8,0x26,0xff,0xac,0x8a,0x83,0x9d,0xb,0x39,0x0,0x39,0x0,0x3a,
  0x0,0x5a,0xb1,0x3f,0x9a,0xe7,0x79,0xde,0xf2,0xc,0x1c,0x5f,0x69,0x3d,0x36,0xf2,
  0x55,0x16,0x40,0x4b,0x90,0x37,0x5e,0xff,0xa8,0x14,0x4a,0xa9,0x8f,0x39,0x4f,0x61,
  0xf3,0xc7,0x6e,0x20,0x4f,0xf3,0xc5,0xaf,0xf0,0x73,0x7e,0x27,0xd7,0x77,0x90,0x5f,
  0xd3,0xa0,0xbe,0x5d,0x8f,0x38,0xfb,0x66,0xeb,0x2a,0x56,0xb4,0x4c,0xa3,0x74,0xde,
  0xdb,0xbc,0xb,0x56,0x37,0xa5,0xa2,0xa9,0x51,0x1e,0xee,0xc3,0x36,0x2c,0x53,0xc9,
  0x67,0xe4,0xa4,0x4e,0xb8,0xc,0xab,0x1b,0xe4,0x9,0x6c,0x7e,0xf5,0x66,0xb,0xb9,
  0x16,0xf6,0x3d,0x47,0x62,0x1b,0x9a,0xf5,0x66,0x4e,0x0,0x20,0x70,0x7e,0xc6,0x9f,
  0x8e,0xcb,0x3,0x7c,0x59,0x7f,0xec,0xa5,0xd,0x8f,0x7c,0xb6,0x92,0x74,0xf0,0xf9,
  0xde,0x5b,0x2a,0xf2,0xbd,0x9a,0x46,0x8a,0xc1,0xa9,0x8b,0xd8,0xef,0xe4,0x42,0x56,
  0x53,0x9b,0xe1,0x8a,0x21,0x33,0xac,0x6d,0x3c,0xb2,0x62,0x48,0xb8,0xfc,0xb7,0xea,
  0x4d,0xe8,0x8b,0x92,0x21,0x19,0x11,0x17,0xa6,0xfd,0x41,0xb1,0xe7,0x4d,0xe3,0x18,
  0x4f,0xc8,0x43,0x1c,0xd9,0xe0,0xc6,0x6d,0x8e,0x69,0xe5,0x3d,0x45,0xc0,0x5d,0x67,
  0x91,0x63,0xbd,0x8e,0xb1,0xf7,0xb3,0x7d,0x1b,0xad,0xcf,0x8f,0xea,0xcd,0x17,0xa5,
  0xb6,0xb0,0x4d,0x1d,0xeb,0xa7,0x26,0x7e,0xd4,0xc4,0x8a,0x7d,0x9d,0xf6,0x2d,0x64,
  0x2d,0x4b,0xac,0xd,0x6a,0xa8,0xa1,0x8a,0xcc,0x48,0x20,0x35,0x93,0xc2,0xc2,0x74,
  0x20,0x44,0xe8,0x34,0xdb,0x36,0x21,0xc,0xc9,0x22,0xc4,0x28,0x63,0x88,0x35,0x52,
  0x43,0x92,0xd4,0xa7,0x38,0xe,0x43,0xbe,0xb9,0xe8,0x3d,0x88,0x76,0xb3,0x17,0x25,
  0x31,0xcf,0x53,0xc8,0x16,0x17,0x6e,0xf3,0x3d,0xf1,0x1e,0x72,0x13,0x3f,0x54,0xe4,
  0xf8,0xbe,0xcc,0x4e,0x16,0x89,0x1,0x82,0x3,0x5a,0xf7,0xc6,0xc4,0x39,0x28,0x4,
  0xae,0x45,0xb7,0x33,0x4d,0x7b,0xec,0x7e,0xed,0x5e,0x19,0xf1,0x57,0xde,0xb3,0x99,
  0xb0,0x82,0xf5,0xc0,0x7d,0x6,0x53,0x72,0xd9,0xbe,0xf,0x19,0x6a,0x81,0x71,0xd5,
  0x7d,0x50,0x92,0x9,0xd1,0xbf,0x81,0x45,0x8e,0x1a,0x5,0xf9,0x97,0x35,0xaa,0x15,
  0x6f,0xd,0x4e,0xd2,0x86,0xea,0x58,0x93,0x3a,0x45,0xb4,0xbd,0x71,0x4f,0xda,0xef,
  0xaf,0xa2,0x98,0x8b,0x42,0x50,0x43,0x5d,0x7b,0xf3,0x58,0x1d,0x83,0x4c,0xef,0x89,
  0x24,0xda,0xc5,0xdf,0xdb,0x47,0xb,0x5,0x6c,0xa2,0xdc,0x7f,0xe2,0xe2,0x4,0x62,
  0x5c,0xce,0x49,0x1a,0x51,0x10,0x1,0x6a,0x5f,0x3e,0x79,0x35,0x62,0x93,0xa,0x29,
  0xea,0xd9,0xdb,0xdd,0x9c,0x4f,0x2c,0x7e,0x1a,0xe8,0x82,0xa,0x2c,0xf,0x14,0xa4,
  0xdd,0xea,0x15,0x3c,0xcb,0xa6,0x9a,0xb,0xce,0x99,0x8c,0x7f,0x3d,0x54,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Treeland
  0x0,0x8,
  0x8,0xbc,0x2f,0x24,
  0x0,0x54,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x4b,0x9c,0x3d,0xd0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x4b,0x9c,0x3d,0xd0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0x4b,0x9c,0x3d,0xd0,
  // :/qt/qml/Treeland
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0x4b,0x9c,0x3d,0xd0,
  // :/qt/qml/Treeland/qmldir
  0x0,0x0,0x0,0x2c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x4b,0x9c,0x3d,0xd0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> treeland-debug-0.7.7-1-x86_64.pkg.tar.zst: usr/src/debug/treeland/treeland/src/.qt/rcc/qrc_qmake_Treeland.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xf0,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x79,0x5,0x35,0xf,0x0,0x76,0x16,0x42,0x1e,0x40,0x8f,0x1b,
  0xfd,0x79,0x73,0x89,0x14,0xfa,0x6d,0x69,0x7f,0x8e,0x64,0xcd,0xcf,0x1d,0x46,0x27,
  0xdb,0x60,0x4f,0xb8,0x26,0xff,0xac,0x8a,0x83,0x9d,0xb,0x39,0x0,0x39,0x0,0x3a,
  0x0,0x5a,0xb1,0x3f,0x9a,0xe7,0x79,0xde,0xf2,0xc,0x1c,0x5f,0x69,0x3d,0x36,0xf2,
  0x55,0x16,0x40,0x4b,0x90,0x37,0x5e,0xff,0xa8,0x14,0x4a,0xa9,0x8f,0x39,0x4f,0x61,
  0xf3,0xc7,0x6e,0x20,0x4f,0xf3,0xc5,0xaf,0xf0,0x73,0x7e,0x27,0xd7,0x77,0x90,0x5f,
  0xd3,0xa0,0xbe,0x5d,0x8f,0x38,0xfb,0x66,0xeb,0x2a,0x56,0xb4,0x4c,0xa3,0x74,0xde,
  0xdb,0xbc,0xb,0x56,0x37,0xa5,0xa2,0xa9,0x51,0x1e,0xee,0xc3,0x36,0x2c,0x53,0xc9,
  0x67,0xe4,0xa4,0x4e,0xb8,0xc,0xab,0x1b,0xe4,0x9,0x6c,0x7e,0xf5,0x66,0xb,0xb9,
  0x16,0xf6,0x3d,0x47,0x62,0x1b,0x9a,0xf5,0x66,0x4e,0x0,0x20,0x70,0x7e,0xc6,0x9f,
  0x8e,0xcb,0x3,0x7c,0x59,0x7f,0xec,0xa5,0xd,0x8f,0x7c,0xb6,0x92,0x74,0xf0,0xf9,
  0xde,0x5b,0x2a,0xf2,0xbd,0x9a,0x46,0x8a,0xc1,0xa9,0x8b,0xd8,0xef,0xe4,0x42,0x56,
  0x53,0x9b,0xe1,0x8a,0x21,0x33,0xac,0x6d,0x3c,0xb2,0x62,0x48,0xb8,0xfc,0xb7,0xea,
  0x4d,0xe8,0x8b,0x92,0x21,0x19,0x11,0x17,0xa6,0xfd,0x41,0xb1,0xe7,0x4d,0xe3,0x18,
  0x4f,0xc8,0x43,0x1c,0xd9,0xe0,0xc6,0x6d,0x8e,0x69,0xe5,0x3d,0x45,0xc0,0x5d,0x67,
  0x91,0x63,0xbd,0x8e,0xb1,0xf7,0xb3,0x7d,0x1b,0xad,0xcf,0x8f,0xea,0xcd,0x17,0xa5,
  0xb6,0xb0,0x4d,0x1d,0xeb,0xa7,0x26,0x7e,0xd4,0xc4,0x8a,0x7d,0x9d,0xf6,0x2d,0x64,
  0x2d,0x4b,0xac,0xd,0x6a,0xa8,0xa1,0x8a,0xcc,0x48,0x20,0x35,0x93,0xc2,0xc2,0x74,
  0x20,0x44,0xe8,0x34,0xdb,0x36,0x21,0xc,0xc9,0x22,0xc4,0x28,0x63,0x88,0x35,0x52,
  0x43,0x92,0xd4,0xa7,0x38,0xe,0x43,0xbe,0xb9,0xe8,0x3d,0x88,0x76,0xb3,0x17,0x25,
  0x31,0xcf,0x53,0xc8,0x16,0x17,0x6e,0xf3,0x3d,0xf1,0x1e,0x72,0x13,0x3f,0x54,0xe4,
  0xf8,0xbe,0xcc,0x4e,0x16,0x89,0x1,0x82,0x3,0x5a,0xf7,0xc6,0xc4,0x39,0x28,0x4,
  0xae,0x45,0xb7,0x33,0x4d,0x7b,0xec,0x7e,0xed,0x5e,0x19,0xf1,0x57,0xde,0xb3,0x99,
  0xb0,0x82,0xf5,0xc0,0x7d,0x6,0x53,0x72,0xd9,0xbe,0xf,0x19,0x6a,0x81,0x71,0xd5,
  0x7d,0x50,0x92,0x9,0xd1,0xbf,0x81,0x45,0x8e,0x1a,0x5,0xf9,0x97,0x35,0xaa,0x15,
  0x6f,0xd,0x4e,0xd2,0x86,0xea,0x58,0x93,0x3a,0x45,0xb4,0xbd,0x71,0x4f,0xda,0xef,
  0xaf,0xa2,0x98,0x8b,0x42,0x50,0x43,0x5d,0x7b,0xf3,0x58,0x1d,0x83,0x4c,0xef,0x89,
  0x24,0xda,0xc5,0xdf,0xdb,0x47,0xb,0x5,0x6c,0xa2,0xdc,0x7f,0xe2,0xe2,0x4,0x62,
  0x5c,0xce,0x49,0x1a,0x51,0x10,0x1,0x6a,0x5f,0x3e,0x79,0x35,0x62,0x93,0xa,0x29,
  0xea,0xd9,0xdb,0xdd,0x9c,0x4f,0x2c,0x7e,0x1a,0xe8,0x82,0xa,0x2c,0xf,0x14,0xa4,
  0xdd,0xea,0x15,0x3c,0xcb,0xa6,0x9a,0xb,0xce,0x99,0x8c,0x7f,0x3d,0x54,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Treeland
  0x0,0x8,
  0x8,0xbc,0x2f,0x24,
  0x0,0x54,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x78,0x5,0x71,0x70,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x78,0x5,0x71,0x70,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0x78,0x5,0x71,0x70,
  // :/qt/qml/Treeland
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0x78,0x5,0x71,0x70,
  // :/qt/qml/Treeland/qmldir
  0x0,0x0,0x0,0x2c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x78,0x5,0x71,0x70,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
